@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "8808faed5f00d377b127b409c9378a23509da0c7",
-  "branchName": "release-client-5.13.5",
-  "buildTime": "Wed, 11 Jan 2023 02:23:12 GMT",
-  "buildVersion": "5.1.171",
+  "commitId": "63d32b0362058179d552cc9ebf734608e30524b3",
+  "branchName": "release-client-5.13.x",
+  "buildTime": "Fri, 24 Feb 2023 08:54:07 GMT",
+  "buildVersion": "5.1.210",
   "css": [
-    "@zoom/client-scheduler/static/css/chunk-vendors.7f57ae19.css",
-    "@zoom/client-scheduler/static/css/index.e12145da.css"
+    "@zoom/client-scheduler/static/css/chunk-vendors.af34567c.css",
+    "@zoom/client-scheduler/static/css/index.0cf63661.css"
   ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.1f90189b.js",
-    "@zoom/client-scheduler/static/js/index.4b129444.js"
+    "@zoom/client-scheduler/static/js/chunk-vendors.2d23d481.js",
+    "@zoom/client-scheduler/static/js/index.9660f796.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
